<?php
/**
 *
 * Sympal theme is a base theme, so it comes with a lot of pre-built code.
 * We aim at consistency, so override almost everything here, and represent it
 * in a consistent way.
 * Feel free to submit new partial files and patches with _phptemplate_callbacks
 * Bèr Kessels carpentered this in webschuur.com for sympal.nl
 */

/**
 * General core functions
 */

/**
 * menu and navigation functions
 * TODO introduce classes like 'active' and 'expanded'
 */
function sympal_theme_primary_links($links) {
  return _phptemplate_callback('primary_links', array('links' => $links));
}
function sympal_theme_secondary_links($links) {
  return _phptemplate_callback('secondary_links', array('links' => $links));
}

function sympal_theme_menu_tree($pid = 1) {
  if ($tree = menu_tree($pid)) {
    // TODO a static var that counts the depth.
    return _phptemplate_callback('menu_tree', array('tree' => $tree, 'pid' => $pid));
  }
}

/**
 * Local tasks AKA tabs
 */
function sympal_theme_menu_local_tasks() {
  $output = '';
  //TODO: build the $links not as an ugly string, but rather an array of items!
  if ($links = menu_primary_local_tasks()) {
    $output = _phptemplate_callback('menu_local_tasks_primary', array('links' => $links));
    $links = '';
  }
  if ($links = menu_secondary_local_tasks()) {
    $output .= _phptemplate_callback('menu_local_tasks_secondary', array('links' => $links));
  }

  return $output;
}

/**
 * A single Localtask AKA tab
 */
function sympal_theme_menu_local_task($mid, $active, $primary) {
  return _phptemplate_callback('menu_local_task', array('mid' => $mid, 'active' => $active));
}
function sympal_theme_menu_item_link($item, $link_item) {
  return _phptemplate_callback('menu_item_link', array('item' => $item, 'link_item' => $link_item));
}

/**
 * Breadcrumbs in a single partial
 */
function sympal_theme_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
    return _phptemplate_callback('breadcrumb', array('links' => $breadcrumb));
  }
}

/**
 * Search form functions
 */
function sympal_theme_search_theme_form($form) {
  return _phptemplate_callback('search_form', array('form' => $form));
}
function sympal_theme_search_block_form($form) {
  return _phptemplate_callback('search_form', array('form' => $form));
}

/**
 * Warning, error and help messages
 */
function sympal_theme_status_messages() {
  if ($data = drupal_get_messages()) {
    foreach ($data as $type => $messages) {
      $grouped_messages .= _phptemplate_callback('status_messages_by_type', array(
        'messages' => $messages,
        'type' => $type,
      ));
    }
    return _phptemplate_callback('status_messages', array(
      'grouped_messages' => $grouped_messages,
    ));
  }
}

/**
 * Special contrib functions for often used modules
 */
/**
 * Flexinode
 */
function sympal_theme_flexinode_textfield($field_id, $label, $value, $formatted_value) {
  return _phptemplate_callback('flexinode_textfield', array(
    'field_id' => $field_id,
    'label' => $label,
    'value' => $value,
    'formatted_value' => $formatted_value,
  ));
}
function sympal_theme_flexinode_image($field_id, $label, $image, $formatted_value) {
  return _phptemplate_callback('flexinode_image', array(
    'field_id' => $field_id,
    'label' => $label,
    'image' => $image,
    'formatted_value' => $formatted_value,
  ));
}

/**
 * New functions introduced here, used as helpers or simpler ways to theme stuff.
 */
/**
 * Terms are now themed trough a way too general theme_links.
 * This function is a helper to render terms in a node.
 */
function sympal_theme_taxonomy_terms_for_node($node) {
  $links = taxonomy_link('taxonomy terms', $node);
  if (count($links)) {
    return _phptemplate_callback('taxonomy_terms_for_node', array('links' => $links, 'terms' => $node->taxonomy, 'node' => $node));
  }
  else {
    return '';
  }
}


/**
 * General phptemplate stuff
 */
/**
 * Make additional variables available and override some core variables
 * TODO: add node counters and zebras
 * TODO: add comment counters and zebras
 */
function _phptemplate_variables($hook, $vars) {
  switch ($hook) {
    case 'page':
    break;
    case 'node':
      $vars['terms'] = theme('taxonomy_terms_for_node', $vars['node']);
    break;
  }
  return $vars;
}

/**
 * define regions
 **/
function sympal_theme_regions() {
  return array(
    'content' => t('content'),
    'branding' => t('branding'),
    'navigation' => t('navigation'),
    'tools' => t('tools'),
    'search' => t('search'),
    'siteinfo' => t('siteinfo'),
    'content_prefix' => t('before content'),
    'content_postfix' => t('after content'),
  );
}
?>